@@ -98,6 +98,7 @@ CREDITS = dict(
         'Koen Benne (Dutch)',
         'Mikachu (Dutch)',
         'Danial Behzadi (Persian)',
+        'Muhammad Hussein Ammari (Persian)',
         'Jiri Grönroos (Finnish)',
         'Ricky Tigg (Finnish)',
         'Irénée THIRION (French)',
@@ -124,11 +125,14 @@ CREDITS = dict(
         'dedocc (Italian)',
         'Davide Mora (Italian)',
         'Andrea Scarano (Italian)',
+        'pasquale ruotolo (Italian)',
+        'Velyvis (Lithuanian)',
         'Lili Kurek (Polish)',
         'Aleksander Warzyniak (Polish)',
         'ssantos (Portuguese)',
         'Ademario Cunha (Portuguese)',
         'SpiralPack 527 (Portuguese)',
+        'Lucas Silva Goulart (Portuguese)',
         'shima (Russian)',
         'Valentin Chernetsov (Russian)',
         'FIONover (Russian)',
@@ -539,29 +543,17 @@ available in your region/language."""))
 
         # Override release notes
         dialog.set_release_notes("""
-            <p>This is a bugfix version.</p>
             <ul>
-                <li>[Card] Fixed Pull-to-Update</li>
-            </ul>
-
-            <p>Changes in previous version 1.79.0</p>
-            <ul>
-                <li>[Card] Added new backdrop method: Blurred cover</li>
-                <li>[Servers] Dragon Ball Multiverse: Update</li>
-                <li>[Servers] EZmanga (EN): Update</li>
+                <li>[Servers] Added MANGA Plus Creators by SHUEISHA (EN/ES)</li>
+                <li>[Servers] Cartel De Manhwas (ES): Update</li>
+                <li>[Servers] Flame Comics (EN): Update</li>
+                <li>[Servers] Lectormanga (ES): Update</li>
                 <li>[Servers] MangaCrab (ES): Update</li>
-                <li>[Servers] MangaMana (FR): Update</li>
-                <li>[Servers] MangaNato (EN): Update</li>
-                <li>[Servers] Mangaowl (EN): Update</li>
-                <li>[Servers] MangaReader (cc) (EN): Update</li>
-                <li>[Servers] Neko Scans(ES): Update</li>
-                <li>[Servers] Pepper&amp;Carrot: Added support of Persian language</li>
-                <li>[Servers] Rawdevart (JA): Update</li>
-                <li>[Servers] Read Comic Online (EN): Update</li>
-                <li>[Servers] Senpai Ediciones (ES): Disabled</li>
-                <li>[Servers] Terco Scans (EN): Update</li>
-                <li>[Servers] Usagi (RU): Disabled</li>
-                <li>[L10n] Updated Arabic and Persian translations</li>
+                <li>[Servers] MangaLib (RU): Update</li>
+                <li>[Servers] Raw Manga (JA): Disabled</li>
+                <li>[Servers] ToonGod (EN): Update</li>
+                <li>[Servers] Webtoon Hatti (TR): Update</li>
+                <li>[L10n] Updated Arabic and Bulgarian translations</li>
             </ul>
             <p>Happy reading.</p>
         """)
